@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -15,23 +15,23 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-#include "hash_sha2_384.h"
+#include "hash_sha2_512_256.h"
 
 namespace mobius
 {
 namespace crypt
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-// initialization constants (FIPS.180-4 - section 5.3.4)
+// initialization constants (FIPS.180-4 - section 5.3.6.2)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static constexpr std::uint64_t H0_VALUE = 0xcbbb9d5dc1059ed8;
-static constexpr std::uint64_t H1_VALUE = 0x629a292a367cd507;
-static constexpr std::uint64_t H2_VALUE = 0x9159015a3070dd17;
-static constexpr std::uint64_t H3_VALUE = 0x152fecd8f70e5939;
-static constexpr std::uint64_t H4_VALUE = 0x67332667ffc00b31;
-static constexpr std::uint64_t H5_VALUE = 0x8eb44a8768581511;
-static constexpr std::uint64_t H6_VALUE = 0xdb0c2e0d64f98fa7;
-static constexpr std::uint64_t H7_VALUE = 0x47b5481dbefa4fa4;
+static constexpr std::uint64_t H0_VALUE = 0x22312194fc2bf72c;
+static constexpr std::uint64_t H1_VALUE = 0x9f555fa3c84c64c2;
+static constexpr std::uint64_t H2_VALUE = 0x2393b86b6f53b151;
+static constexpr std::uint64_t H3_VALUE = 0x963877195940eabd;
+static constexpr std::uint64_t H4_VALUE = 0x96283ee2a88effe3;
+static constexpr std::uint64_t H5_VALUE = 0xbe5e1e2553863992;
+static constexpr std::uint64_t H6_VALUE = 0x2b0199fc2c85b8aa;
+static constexpr std::uint64_t H7_VALUE = 0x0eb72ddc81c52ca2;
 
 //! \brief block size = 128 bytes (1024 bits) - FIPS.180-4 - section 1
 static constexpr int BLOCK_SIZE = 128;
@@ -51,7 +51,7 @@ rrot (std::uint64_t v, std::uint64_t n) noexcept
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief default constructor
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-hash_sha2_384::hash_sha2_384 () noexcept
+hash_sha2_512_256::hash_sha2_512_256 () noexcept
   : hash_block (BLOCK_SIZE),
     a_ (H0_VALUE),
     b_ (H1_VALUE),
@@ -69,7 +69,7 @@ hash_sha2_384::hash_sha2_384 () noexcept
 //! \brief reset hash value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha2_384::_reset () noexcept
+hash_sha2_512_256::_reset () noexcept
 {
   a_ = H0_VALUE;
   b_ = H1_VALUE;
@@ -88,7 +88,7 @@ hash_sha2_384::_reset () noexcept
 //! \see FIPS.180-4 - section 6.2
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha2_384::_update_block (const mobius::bytearray& data) noexcept
+hash_sha2_512_256::_update_block (const mobius::bytearray& data) noexcept
 {
   std::uint64_t a = a_;
   std::uint64_t b = b_;
@@ -1201,9 +1201,9 @@ hash_sha2_384::_update_block (const mobius::bytearray& data) noexcept
 // representing the message size in bits (FIPS.180-4 - section 5.1.2)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::bytearray
-hash_sha2_384::_evaluate (const mobius::bytearray& data)
+hash_sha2_512_256::_evaluate (const mobius::bytearray& data)
 {
-  hash_sha2_384 tmp (*this);
+  hash_sha2_512_256 tmp (*this);
 
   // represent message size in bits as a bytearray
   std::uint64_t bits = ((size_ + data.size ()) << 3);
@@ -1288,22 +1288,6 @@ hash_sha2_384::_evaluate (const mobius::bytearray& data)
     std::uint8_t (d_ >> 16),
     std::uint8_t (d_ >> 8),
     std::uint8_t (d_),
-    std::uint8_t (e_ >> 56),
-    std::uint8_t (e_ >> 48),
-    std::uint8_t (e_ >> 40),
-    std::uint8_t (e_ >> 32),
-    std::uint8_t (e_ >> 24),
-    std::uint8_t (e_ >> 16),
-    std::uint8_t (e_ >> 8),
-    std::uint8_t (e_),
-    std::uint8_t (f_ >> 56),
-    std::uint8_t (f_ >> 48),
-    std::uint8_t (f_ >> 40),
-    std::uint8_t (f_ >> 32),
-    std::uint8_t (f_ >> 24),
-    std::uint8_t (f_ >> 16),
-    std::uint8_t (f_ >> 8),
-    std::uint8_t (f_),
   };
 
   *this = tmp;
